==> zio-aws-lambda_2.12-7.21.15.8-sources.jar: zio/aws/lambda/model/SelfManagedKafkaEventSourceConfig.scala <==
package zio.aws.lambda.model
import zio.aws.lambda.model.primitives.URI
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SelfManagedKafkaEventSourceConfig(
    consumerGroupId: Optional[URI] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig = {
    import SelfManagedKafkaEventSourceConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
      .builder()
      .optionallyWith(
        consumerGroupId.map(value => URI.unwrap(value): java.lang.String)
      )(_.consumerGroupId)
      .build()
  }
  def asReadOnly
      : zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.ReadOnly =
    zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.wrap(buildAwsValue())
}
object SelfManagedKafkaEventSourceConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig =
      zio.aws.lambda.model
        .SelfManagedKafkaEventSourceConfig(consumerGroupId.map(value => value))
    def consumerGroupId: Optional[URI]
    def getConsumerGroupId: ZIO[Any, AwsError, URI] =
      AwsError.unwrapOptionField("consumerGroupId", consumerGroupId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
  ) extends zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.ReadOnly {
    override val consumerGroupId: Optional[URI] = zio.aws.core.internal
      .optionalFromNullable(impl.consumerGroupId())
      .map(value => zio.aws.lambda.model.primitives.URI(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
  ): zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lambda_3-5.17.269.1-sources.jar: zio/aws/lambda/model/SelfManagedKafkaEventSourceConfig.scala <==
package zio.aws.lambda.model
import zio.aws.lambda.model.primitives.URI
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SelfManagedKafkaEventSourceConfig(
    consumerGroupId: Optional[URI] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig = {
    import SelfManagedKafkaEventSourceConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
      .builder()
      .optionallyWith(
        consumerGroupId.map(value => URI.unwrap(value): java.lang.String)
      )(_.consumerGroupId)
      .build()
  }
  def asReadOnly
      : zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.ReadOnly =
    zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.wrap(buildAwsValue())
}
object SelfManagedKafkaEventSourceConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig =
      zio.aws.lambda.model
        .SelfManagedKafkaEventSourceConfig(consumerGroupId.map(value => value))
    def consumerGroupId: Optional[URI]
    def getConsumerGroupId: ZIO[Any, AwsError, URI] =
      AwsError.unwrapOptionField("consumerGroupId", consumerGroupId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
  ) extends zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.ReadOnly {
    override val consumerGroupId: Optional[URI] = zio.aws.core.internal
      .optionalFromNullable(impl.consumerGroupId())
      .map(value => zio.aws.lambda.model.primitives.URI(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lambda.model.SelfManagedKafkaEventSourceConfig
  ): zio.aws.lambda.model.SelfManagedKafkaEventSourceConfig.ReadOnly =
    new Wrapper(impl)
}
